@@ -24,7 +24,7 @@ import shutil
 from functools import reduce
 from operator import getitem
 from pathlib import Path
-from typing import Any, Dict, List, Union
+from typing import Any, Dict, List, Optional, Union
 
 import toml
 
@@ -74,27 +74,37 @@ class _ConfigManager:
         # self.config_data may be modified later, and we don't want it to affect _DEFAULT_CONFIG
         self.config_data = copy.deepcopy(_DEFAULT_CONFIG)
 
-    def update_config(self) -> None:
+    def update_config(self, new_entries: Optional[Dict] = None, defaults: bool = False) -> None:
         """
         Update the exising configuration dictionary with the configuration stored in file.
+            Optionally, update configuration data with an input dict.
 
         Args:
-            None
+            new_entries: Dictionary of new entries added or updated in the config
+            defaults: If False (which is the default), default values do not overwrite
+                existing entries.
 
         Returns:
             None
         """
 
-        def update_nested_dict(old_dict, new_dict):
+        def update_nested_dict(old_dict, new_dict, defaults: bool = False):
             for key, value in new_dict.items():
                 if isinstance(value, dict) and key in old_dict and isinstance(old_dict[key], dict):
-                    update_nested_dict(old_dict[key], value)
+                    update_nested_dict(old_dict[key], value, defaults)
                 else:
-                    old_dict[key] = value
+                    if defaults:  # Values provided are defaults
+                        old_dict.setdefault(key, value)
+                    else:  # Values provided should overwrite
+                        old_dict[key] = value
 
         if os.path.exists(self.config_file):
             file_config = toml.load(self.config_file)
             update_nested_dict(self.config_data, file_config)
+            if new_entries:
+                update_nested_dict(self.config_data, new_entries, defaults)
+
+        self.write_config()
 
     def read_config(self) -> None:
         """
@@ -164,7 +174,15 @@ class _ConfigManager:
         """
 
         keys = key.split(".")
-        reduce(getitem, keys[:-1], self.config_data)[keys[-1]] = value
+
+        try:
+            reduce(getitem, keys[:-1], self.config_data)[keys[-1]] = value
+        except KeyError:
+            data = self.config_data
+            for key in keys:
+                data[key] = {}
+                data = data[key]
+            data[keys[-1]] = value
 
 
 _config_manager = _ConfigManager()
@@ -236,3 +254,21 @@ def reload_config() -> None:
     """
 
     _config_manager.read_config()
+
+
+def update_config(new_entries: Optional[Dict] = None, defaults: bool = False) -> None:
+    """
+    Read the configuration from the TOML file and append to default
+        (or existing) configuration. Optionally, update configuration
+        data with an input dict.
+
+    Args:
+        new_entries: Dictionary of new entries added or updated in the config
+        defaults: If False (which is the default), default values do not overwrite
+            existing entries.
+
+    Returns:
+        None
+    """
+
+    _config_manager.update_config(new_entries, defaults)
